aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--build/cxx/rule.cxx13
1 files changed, 11 insertions, 2 deletions
diff --git a/build/cxx/rule.cxx b/build/cxx/rule.cxx
index f63c92a..c9d451d 100644
--- a/build/cxx/rule.cxx
+++ b/build/cxx/rule.cxx
@@ -59,9 +59,18 @@ namespace build
{
const string& v (val.as<const string&> ());
// @@ Need to translate 11 to 0x for older versions.
//
- opt = "-std=c++" + v;
+ opt = "-std=c++";
+
+ if (v == "11")
+ opt += "0x";
+ else if (v == "14")
+ opt += "1y";
+ else
+ opt += v;
+
args.push_back (opt.c_str ());
}
}
@@ -59,9 +59,18 @@ namespace build
{
const string& v (val.as<const string&> ());
- // @@ Need to translate 11 to 0x for older versions.
+ // Translate 11 to 0x and 14 to 1y for compatibility with
+ // older versions of the compiler.
//